@@ -33,9 +33,10 @@
 #  define AKONADI_CALENDAR_DEPRECATED_NO_EXPORT AKONADI_CALENDAR_NO_EXPORT AKONADI_CALENDAR_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define AKONADI_CALENDAR_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef AKONADI_CALENDAR_NO_DEPRECATED
+#    define AKONADI_CALENDAR_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
