@@ -33,9 +33,10 @@
 #  define AKONADI_KMIME_DEPRECATED_NO_EXPORT AKONADI_KMIME_NO_EXPORT AKONADI_KMIME_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define AKONADI_KMIME_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef AKONADI_KMIME_NO_DEPRECATED
+#    define AKONADI_KMIME_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
