@@ -33,9 +33,10 @@
 #  define AKONADI_NOTES_DEPRECATED_NO_EXPORT AKONADI_NOTES_NO_EXPORT AKONADI_NOTES_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define AKONADI_NOTES_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef AKONADI_NOTES_NO_DEPRECATED
+#    define AKONADI_NOTES_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
