@@ -33,9 +33,10 @@
 #  define LIBAKONADISOCIALUTILS_DEPRECATED_NO_EXPORT LIBAKONADISOCIALUTILS_NO_EXPORT LIBAKONADISOCIALUTILS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define LIBAKONADISOCIALUTILS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef LIBAKONADISOCIALUTILS_NO_DEPRECATED
+#    define LIBAKONADISOCIALUTILS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
