@@ -33,9 +33,10 @@
 #  define GPGMEPP_DEPRECATED_NO_EXPORT GPGMEPP_NO_EXPORT GPGMEPP_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define GPGMEPP_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef GPGMEPP_NO_DEPRECATED
+#    define GPGMEPP_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
