@@ -33,9 +33,10 @@
 #  define KABC_DEPRECATED_NO_EXPORT KABC_NO_EXPORT KABC_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KABC_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KABC_NO_DEPRECATED
+#    define KABC_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
