@@ -33,9 +33,10 @@
 #  define KBLOG_DEPRECATED_NO_EXPORT KBLOG_NO_EXPORT KBLOG_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KBLOG_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KBLOG_NO_DEPRECATED
+#    define KBLOG_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
