@@ -33,9 +33,10 @@
 #  define KCAL_DEPRECATED_NO_EXPORT KCAL_NO_EXPORT KCAL_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KCAL_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KCAL_NO_DEPRECATED
+#    define KCAL_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
