@@ -33,9 +33,10 @@
 #  define KCALCORE_DEPRECATED_NO_EXPORT KCALCORE_NO_EXPORT KCALCORE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KCALCORE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KCALCORE_NO_DEPRECATED
+#    define KCALCORE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
