@@ -33,9 +33,10 @@
 #  define KCALUTILS_DEPRECATED_NO_EXPORT KCALUTILS_NO_EXPORT KCALUTILS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KCALUTILS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KCALUTILS_NO_DEPRECATED
+#    define KCALUTILS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
