@@ -33,9 +33,10 @@
 #  define KHOLIDAYS_DEPRECATED_NO_EXPORT KHOLIDAYS_NO_EXPORT KHOLIDAYS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KHOLIDAYS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KHOLIDAYS_NO_DEPRECATED
+#    define KHOLIDAYS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
