@@ -33,9 +33,10 @@
 #  define KIMAP_DEPRECATED_NO_EXPORT KIMAP_NO_EXPORT KIMAP_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KIMAP_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KIMAP_NO_DEPRECATED
+#    define KIMAP_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
