@@ -33,9 +33,10 @@
 #  define KMBOX_DEPRECATED_NO_EXPORT KMBOX_NO_EXPORT KMBOX_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KMBOX_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KMBOX_NO_DEPRECATED
+#    define KMBOX_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
