@@ -33,9 +33,10 @@
 #  define KMIME_DEPRECATED_NO_EXPORT KMIME_NO_EXPORT KMIME_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KMIME_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KMIME_NO_DEPRECATED
+#    define KMIME_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
