@@ -33,9 +33,10 @@
 #  define KONTACTINTERFACE_DEPRECATED_NO_EXPORT KONTACTINTERFACE_NO_EXPORT KONTACTINTERFACE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KONTACTINTERFACE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KONTACTINTERFACE_NO_DEPRECATED
+#    define KONTACTINTERFACE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
