@@ -33,9 +33,10 @@
 #  define KPIMIDENTITIES_DEPRECATED_NO_EXPORT KPIMIDENTITIES_NO_EXPORT KPIMIDENTITIES_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KPIMIDENTITIES_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KPIMIDENTITIES_NO_DEPRECATED
+#    define KPIMIDENTITIES_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
