@@ -33,9 +33,10 @@
 #  define KPIMTEXTEDIT_DEPRECATED_NO_EXPORT KPIMTEXTEDIT_NO_EXPORT KPIMTEXTEDIT_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KPIMTEXTEDIT_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KPIMTEXTEDIT_NO_DEPRECATED
+#    define KPIMTEXTEDIT_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
