@@ -33,9 +33,10 @@
 #  define KPIMUTILS_DEPRECATED_NO_EXPORT KPIMUTILS_NO_EXPORT KPIMUTILS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KPIMUTILS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KPIMUTILS_NO_DEPRECATED
+#    define KPIMUTILS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
