@@ -33,9 +33,10 @@
 #  define KRESOURCES_DEPRECATED_NO_EXPORT KRESOURCES_NO_EXPORT KRESOURCES_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KRESOURCES_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KRESOURCES_NO_DEPRECATED
+#    define KRESOURCES_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
