@@ -33,9 +33,10 @@
 #  define KTNEF_DEPRECATED_NO_EXPORT KTNEF_NO_EXPORT KTNEF_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KTNEF_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KTNEF_NO_DEPRECATED
+#    define KTNEF_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
