@@ -33,9 +33,10 @@
 #  define MAILTRANSPORT_DEPRECATED_NO_EXPORT MAILTRANSPORT_NO_EXPORT MAILTRANSPORT_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define MAILTRANSPORT_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef MAILTRANSPORT_NO_DEPRECATED
+#    define MAILTRANSPORT_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
