@@ -33,9 +33,10 @@
 #  define MICROBLOG_DEPRECATED_NO_EXPORT MICROBLOG_NO_EXPORT MICROBLOG_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define MICROBLOG_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef MICROBLOG_NO_DEPRECATED
+#    define MICROBLOG_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
