@@ -33,9 +33,10 @@
 #  define QGPGME_DEPRECATED_NO_EXPORT QGPGME_NO_EXPORT QGPGME_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define QGPGME_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef QGPGME_NO_DEPRECATED
+#    define QGPGME_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
