@@ -33,9 +33,10 @@
 #  define SYNDICATION_DEPRECATED_NO_EXPORT SYNDICATION_NO_EXPORT SYNDICATION_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define SYNDICATION_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef SYNDICATION_NO_DEPRECATED
+#    define SYNDICATION_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
